pub struct DisplayListDevice<'a> { /* private fields */ }Expand description
A device that records drawing commands into a display list.
This wrapper carries the mutable borrow of the display list for as long as the recording device is alive, preventing safe Rust code from reading or recording the same list concurrently.
Methods from Deref<Target = Device>
Sourcepub fn fill_path(
&self,
path: &Path,
even_odd: bool,
ctm: &Matrix,
cs: &Colorspace,
color: &[f32],
alpha: f32,
cp: ColorParams,
) -> Result<(), Error>
pub fn fill_path( &self, path: &Path, even_odd: bool, ctm: &Matrix, cs: &Colorspace, color: &[f32], alpha: f32, cp: ColorParams, ) -> Result<(), Error>
The colors in color must match the colorspace cs, as described in
Colorspace::convert_color
Sourcepub fn stroke_path(
&self,
path: &Path,
stroke: &StrokeState,
ctm: &Matrix,
cs: &Colorspace,
color: &[f32],
alpha: f32,
cp: ColorParams,
) -> Result<(), Error>
pub fn stroke_path( &self, path: &Path, stroke: &StrokeState, ctm: &Matrix, cs: &Colorspace, color: &[f32], alpha: f32, cp: ColorParams, ) -> Result<(), Error>
The colors in color must match the colorspace cs, as described in
Colorspace::convert_color
pub fn clip_path( &self, path: &Path, even_odd: bool, ctm: &Matrix, ) -> Result<(), Error>
pub fn clip_stroke_path( &self, path: &Path, stroke: &StrokeState, ctm: &Matrix, ) -> Result<(), Error>
Sourcepub fn fill_text(
&self,
text: &Text,
ctm: &Matrix,
cs: &Colorspace,
color: &[f32],
alpha: f32,
cp: ColorParams,
) -> Result<(), Error>
pub fn fill_text( &self, text: &Text, ctm: &Matrix, cs: &Colorspace, color: &[f32], alpha: f32, cp: ColorParams, ) -> Result<(), Error>
The colors in color must match the colorspace cs, as described in
Colorspace::convert_color
Sourcepub fn stroke_text(
&self,
text: &Text,
stroke: &StrokeState,
ctm: &Matrix,
cs: &Colorspace,
color: &[f32],
alpha: f32,
cp: ColorParams,
) -> Result<(), Error>
pub fn stroke_text( &self, text: &Text, stroke: &StrokeState, ctm: &Matrix, cs: &Colorspace, color: &[f32], alpha: f32, cp: ColorParams, ) -> Result<(), Error>
The colors in color must match the colorspace cs, as described in
Colorspace::convert_color
pub fn clip_text(&self, text: &Text, ctm: &Matrix) -> Result<(), Error>
pub fn clip_stroke_text( &self, text: &Text, stroke: &StrokeState, ctm: &Matrix, ) -> Result<(), Error>
pub fn ignore_text(&self, text: &Text, ctm: &Matrix) -> Result<(), Error>
pub fn fill_shade( &self, shd: &Shade, ctm: &Matrix, alpha: f32, cp: ColorParams, ) -> Result<(), Error>
pub fn fill_image( &self, image: &Image, ctm: &Matrix, alpha: f32, cp: ColorParams, ) -> Result<(), Error>
Sourcepub fn fill_image_mask(
&self,
image: &Image,
ctm: &Matrix,
cs: &Colorspace,
color: &[f32],
alpha: f32,
cp: ColorParams,
) -> Result<(), Error>
pub fn fill_image_mask( &self, image: &Image, ctm: &Matrix, cs: &Colorspace, color: &[f32], alpha: f32, cp: ColorParams, ) -> Result<(), Error>
The colors in color must match the colorspace cs, as described in
Colorspace::convert_color
pub fn clip_image_mask(&self, image: &Image, ctm: &Matrix) -> Result<(), Error>
pub fn pop_clip(&self) -> Result<(), Error>
pub fn begin_mask( &self, area: Rect, luminosity: bool, cs: &Colorspace, bc: &[f32], cp: ColorParams, ) -> Result<(), Error>
pub fn end_mask(&self, f: Option<&Function>) -> Result<(), Error>
pub fn begin_group( &self, area: Rect, cs: &Colorspace, isolated: bool, knockout: bool, blend_mode: BlendMode, alpha: f32, ) -> Result<(), Error>
pub fn end_group(&self) -> Result<(), Error>
pub fn begin_tile( &self, area: Rect, view: Rect, xstep: f32, ystep: f32, ctm: &Matrix, id: Option<NonZero<i32>>, doc_id: Option<NonZero<i32>>, ) -> Result<Option<NonZero<i32>>, Error>
pub fn end_tile(&self) -> Result<(), Error>
pub fn begin_layer(&self, name: &str) -> Result<(), Error>
pub fn end_layer(&self) -> Result<(), Error>
pub fn begin_structure( &self, standard: Structure, raw: &str, idx: i32, ) -> Result<(), Error>
pub fn end_structure(&self) -> Result<(), Error>
pub fn begin_metatext(&self, meta: Metatext, text: &str) -> Result<(), Error>
pub fn end_metatext(&self) -> Result<(), Error>